.. :changelog:

History
-------

0.1.0 (2013-10-08)
++++++++++++++++++

* First release.

0.1.1 (2013-10-11)
++++++++++++++++++

* Added support for custom adf.ly domains via the type='adfly' variable.

0.1.2 (2013-10-11)
++++++++++++++++++

* Fixed bug with t.co not working.

0.1.3 (2013-10-11)
++++++++++++++++++

* Added a timeout parameter

0.1.4 (2013-10-12)
++++++++++++++++++

* Added support for p.ost.im.
* Fixed blocking issue with direct links to file downloads

0.1.5 (2014-02-01)
++++++++++++++++++

* Fixed adfoc.us issues resulting from changes to their site
* Fixed linkbucks.com issues resulting from changes to their site